@@ -94,7 +94,7 @@ sub files {
     # ignore embedded jQuery libraries for Doxygen (#736360)
     unless (
         $file->basename eq 'jquery.js'
-        && defined$self->info->index_resolved_path(
+        && defined$self->processable->index_resolved_path(
             $file->dirname . 'doxygen.css'
         )
     ) {
@@ -150,7 +150,7 @@ sub files {
 
     # embedded Feedparser library
     if (    $file->name =~ m,/feedparser\.py$,
-        and $self->processable->pkg_src ne 'feedparser'){
+        and $self->processable->source ne 'feedparser'){
 
         my $fd = $file->open;
         while (<$fd>) {
